@@ -123,8 +123,6 @@ $(window).on('entity:map', function (e, data) {
         map.boxZoom.disable();
     }
 
-    map.attributionControl.setPrefix('');
-
     var mapBounds = $container.data('mapextent');
     if (mapBounds) {
         map.fitBounds(mapBounds);
@@ -231,10 +229,8 @@ $(window).on('entity:map:list', function (e, data) {
     var map = data.map,
         bounds = L.latLngBounds(data.options.extent);
 
-    map.removeControl(map.attributionControl);
     map.doubleClickZoom.disable();
 
-    map.addControl(new L.Control.Information());
     map.addControl(new L.Control.ResetView(bounds));
 
     /*
@@ -351,6 +347,7 @@ $(window).on('entity:map:list', function (e, data) {
             prefix: 'list',
         }
     );
+
     $(window).unload(function () {
         MapEntity.Context.saveFullContext(map, {
             filter: '#mainfilter',
