@@ -19,6 +19,7 @@ from .generic import (
     MapEntityMarkupWeasyprint,
     DocumentConvert,
     MapEntityCreate,
+    MapEntityDuplicate,
     MapEntityDetail,
     MapEntityUpdate,
     MapEntityDelete,
@@ -38,6 +39,7 @@ MAPENTITY_GENERIC_VIEWS = [
     MapEntityDocument,
     MapEntityMarkupWeasyprint,
     MapEntityCreate,
+    MapEntityDuplicate,
     MapEntityDetail,
     MapEntityUpdate,
     MapEntityDelete,
@@ -55,6 +57,7 @@ __all__ = [
     'MapEntityMarkupWeasyprint',
     'DocumentConvert',
     'MapEntityCreate',
+    'MapEntityDuplicate',
     'MapEntityDetail',
     'MapEntityUpdate',
     'MapEntityDelete',
