@@ -2,11 +2,14 @@ import json
 import logging
 import os
 from datetime import datetime
+from urllib.parse import parse_qs, urlencode, urlparse, urlunparse
 
 from django.conf import settings
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
+from django.contrib.staticfiles.storage import staticfiles_storage
 from django.core.exceptions import PermissionDenied
+from django.core.files.storage import default_storage
 from django.http import HttpResponse, HttpResponseBadRequest, HttpResponseRedirect
 from django.template.defaultfilters import slugify
 from django.template.exceptions import TemplateDoesNotExist
@@ -22,13 +25,15 @@ from django.views.generic.list import ListView
 from django_weasyprint import WeasyTemplateResponseMixin
 from djappypod.response import OdtTemplateResponse
 
+from mapentity.tokens import TokenManager
+
 from .base import history_delete, BaseListView
 from .mixins import (ModelViewMixin, FormViewMixin)
 from .. import models as mapentity_models
 from .. import serializers as mapentity_serializers
 from ..decorators import save_history, view_permission_required
 from ..forms import AttachmentForm
-from ..helpers import convertit_url, download_to_stream, user_has_perm
+from ..helpers import convertit_url, download_content, user_has_perm
 from ..helpers import suffix_for, name_for, smart_get_template
 from ..models import LogEntry, ADDITION, CHANGE, DELETION
 from ..settings import app_settings
@@ -71,7 +76,7 @@ class MapEntityList(BaseListView, ListView):
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
         context['filterform'] = self._filterform  # From FilterListMixin
-        context['columns'] = self.columns  # From BaseListView
+        context['columns'] = self.get_columns()  # From BaseListView
         context['unorderable_columns'] = self.unorderable_columns  # From BaseListView
         context['searchable_columns'] = self.searchable_columns  # From BaseListView
         context['create_label'] = self.get_model().get_create_label()
@@ -126,14 +131,14 @@ class MapEntityFormat(BaseListView, ListView):
         serializer = mapentity_serializers.CSVSerializer()
         response = HttpResponse(content_type='text/csv')
         serializer.serialize(queryset=self.get_queryset(), stream=response,
-                             model=self.get_model(), fields=self.columns, ensure_ascii=True)
+                             model=self.get_model(), fields=self.get_columns(), ensure_ascii=True)
         return response
 
     def shape_view(self, request, context, **kwargs):
         serializer = mapentity_serializers.ZipShapeSerializer()
         response = HttpResponse(content_type='application/zip')
         serializer.serialize(queryset=self.get_queryset(), model=self.get_model(),
-                             stream=response, fields=self.columns)
+                             stream=response, fields=self.get_columns())
         response['Content-length'] = str(len(response.content))
         return response
 
@@ -162,7 +167,7 @@ class MapEntityMapImage(ModelViewMixin, DetailView):
             if not self.request.user.has_perm('%s.read_%s' % (obj._meta.app_label, obj._meta.model_name)):
                 raise PermissionDenied
         obj.prepare_map_image(self.request.build_absolute_uri('/'))
-        path = obj.get_map_image_path().replace(settings.MEDIA_ROOT, '').lstrip('/')
+        path = obj.get_map_image_path()
         if settings.DEBUG or not app_settings['SENDFILE_HTTP_HEADER']:
             response = static.serve(self.request, path, settings.MEDIA_ROOT)
         else:
@@ -193,13 +198,14 @@ class MapEntityDocumentBase(ModelViewMixin, DetailView):
         context = super().get_context_data(**kwargs)
         context['datetime'] = datetime.now()
         context['objecticon'] = os.path.join(settings.STATIC_ROOT, self.get_entity().icon_big)
-        context['logo_path'] = os.path.join(settings.MEDIA_ROOT, 'upload/logo-header.png')
-        if not os.path.exists(context['logo_path']):
-            context['logo_path'] = os.path.join(settings.STATIC_ROOT, 'images/logo-header.png')
-        context['STATIC_URL'] = self.request.build_absolute_uri(settings.STATIC_URL)
-        context['STATIC_ROOT'] = settings.STATIC_ROOT
-        context['MEDIA_URL'] = self.request.build_absolute_uri(settings.MEDIA_URL)
-        context['MEDIA_ROOT'] = settings.MEDIA_ROOT
+        if default_storage.exists('upload/logo-header.png'):
+            context['logo_path'] = default_storage.path('upload/logo-header.png')
+        else:
+            context['logo_path'] = staticfiles_storage.path('images/logo-header.png')
+        context['STATIC_URL'] = staticfiles_storage.base_url
+        context['STATIC_ROOT'] = staticfiles_storage.location
+        context['MEDIA_URL'] = default_storage.base_url
+        context['MEDIA_ROOT'] = default_storage.location
         return context
 
 
@@ -219,7 +225,7 @@ class MapEntityWeasyprint(MapEntityDocumentBase):
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
-        context['map_path'] = self.get_object().get_map_image_path()
+        context['map_path'] = self.get_object().map_image_path
         context['template_attributes'] = self.template_attributes
         context['template_css'] = self.template_css
         return context
@@ -235,6 +241,18 @@ class MapEntityMarkupWeasyprint(MapEntityWeasyprint):
     def get_entity_kind(cls):
         return mapentity_models.ENTITY_MARKUP
 
+    def patch_static_file_paths(self, content):
+        """ Patch weasyprint renderer content to switch file://xxx paths to html scheme """
+        file_paths_media = f"file://{default_storage.location}"
+        new_content = content.replace(file_paths_media, default_storage.base_url)
+        file_paths_static = f"file://{staticfiles_storage.location}"
+        return new_content.replace(file_paths_static, staticfiles_storage.base_url)
+
+    def render_to_response(self, context, **response_kwargs):
+        response = super().render_to_response(context, **response_kwargs)
+        response.content = self.patch_static_file_paths(response.rendered_content)
+        return response
+
 
 class MapEntityDocumentOdt(MapEntityDocumentBase):
     response_class = OdtTemplateResponse
@@ -287,15 +305,32 @@ class Convert(View):
 
         fromtype = request.GET.get('from')
         format = request.GET.get('to', self.format)
-        url = convertit_url(source, from_type=fromtype, to_type=format)
+
+        # Parse and unparse to add the auth_token inside the URL
+        parse_url = urlparse(source)
+        url_parameters = parse_qs(parse_url.query)
+
+        # Adds the token
+        auth_token = TokenManager.generate_token()
+        url_parameters["auth_token"] = [auth_token]
+
+        query = urlencode(url_parameters, doseq=True)
+        new_query_with_token = parse_url._replace(query=query)
+        url_with_token = urlunparse(new_query_with_token)
+
+        source_url = f"{url_with_token}"
+        url = convertit_url(source_url, from_type=fromtype, to_type=format)
 
         response = HttpResponse()
-        received = download_to_stream(url, response,
-                                      silent=True,
-                                      headers=self.request_headers())
+        received = download_content(url,
+                                    silent=True,
+                                    headers=self.request_headers())
         if received:
-            filename = os.path.basename(received.url)
-            response['Content-Disposition'] = 'attachment; filename=%s' % filename
+            response = HttpResponse(received)
+            parsed_url = urlparse(source_url)
+            original_filename = os.path.basename(parsed_url.path)
+            converted_filename = f"{os.path.splitext(original_filename)[0]}.{format}"
+            response['Content-Disposition'] = 'attachment; filename=%s' % converted_filename
         return response
 
     def request_headers(self):
@@ -489,16 +524,7 @@ class MapEntityDelete(ModelViewMixin, DeleteView):
     def dispatch(self, *args, **kwargs):
         return super().dispatch(*args, **kwargs)
 
-    def delete(self, request, *args, **kwargs):
-        """ view exists in django <= 3.2, not anymore in 4.0 """
-        self.object = self.get_object()
-        log_action(self.request, self.object, DELETION)
-        # Remove entry from history
-        history_delete(request, path=self.object.get_detail_url())
-        return super().delete(request, *args, **kwargs)
-
     def form_valid(self, form):
-        """ view not exists for django <= 3.2, but in 4.0 """
         log_action(self.request, self.object, DELETION)
         # Remove entry from history
         history_delete(self.request, path=self.object.get_detail_url())
